/**
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Dejbjerg Pedersen, Lenio
 *   Hans Guldager Knudsen, Lenio
 *   Patrik Johansson, Accenture
 *   Dennis Søgaard, Accenture
 *   Martin Bentzen, Accenture
 *   Jesper Jensen, Avanade
 *   Ramzi Fadel, Avanade
 *   Christian Pedersen, Accenture
 *   Morten Hougesen, Accenture
 *   Mikkel Hippe Brun, ITST
 *   Finn Hartmann Jordal, ITST
 *   Christian Lanng, ITST
 *
 */

package dk.gov.oiosi.uddi;

import dk.gov.oiosi.common.Guid;
import dk.gov.oiosi.exception.NullOrEmptyArgumentException;

/**
 * Represents a UDDI type guid.
 */
public class UddiGuidId extends UddiId {

    /**
     * Original guid : private Guid _guid; Guid is Microsoft UUID - represent as
     * string in java/axis
     */
    private Guid _guid;

    /**
     * Creates a new GUID
     */
    public UddiGuidId() {
        _guid = Guid.newGuid();
    }

    /**
     * Tests a guid to see if it is a valid uddi guid
     * 
     * @param guid
     *            guid to test
     * @param isUddiType
     *            indicates if it is a uddi type guid
     * @return Returns true if the guid is valid
     */
    public static boolean isValidGuidId(String guid, boolean isUddiType) {
        if (guid == null || guid.length() == 0)
            return false;

        String guidString = "";

        if (isUddiType) {
            guidString = guid.substring(5);
        } else {
            guidString = guid;
        }

        return Guid.validateString(guidString);
    }

    /**
     * Constructs a new GUID class from an existing GUID string
     * 
     * @param guid The guid as a string
     * @param isUddiType Whether or not the GUID has a uddi prefix
     */
    public UddiGuidId(String guid, boolean isUddiType) {
        if (guid == null || guid.length() == 0)
            throw new NullOrEmptyArgumentException("guid");

        String guidString = "";
        if (isUddiType) {
            guidString = guid.substring(5);
        } else {
            guidString = guid;
        }

        _guid = new Guid(guidString);
    }

    /**
     * Constructs a uddi guid given an guid string. String must not have a "uddi:" prefix.
     * 
     * @param guid The guid string
     */
    public UddiGuidId(String guid) throws UddiEmptyGuidException {
        if (guid == null || guid.length() == 0) {
            throw new UddiEmptyGuidException();
        }
        _guid = new Guid(guid);
    }

    /**
     * Constructs a uddi guid given a uddi id
     * 
     * @param Id The UDDI id
     */
    public UddiGuidId(UddiId Id) throws UddiException {
        this(Id.getID(), true);
    }

    /**
     * Gets the guid with a "uddi:" prefix
     */
    public String getID() {
        return "uddi:" + _guid; // .ToString();
    }

    /**
     * Gets as string
     * 
     * @return string
     */
    public String toString() {
        return getID();
    }
}